Slocum -- A tool for ocean passage planning
===========================================

**slocum** is an open source project which provides weather forecasts
to the bandwidth impaired (primarily sailors).  It includes a weather
specific compression algorithm which results in forecasts attachments
that are the fraction of the size of `saildoc <http://www.saildocs.com/>`_
forecasts.

Why the name **slocum**?
------------------------

Joshua Slocum (February 20, 1844 -on or shortly after November 14, 1909)
was a Canadian-American seaman and adventurer, a noted writer, and the first
man to sail single-handedly around the world. In 1900 he told the story of
this in Sailing Alone Around the World. He disappeared in November 1909
while aboard his boat, the Spray. (wikipedia)

In "Sailing Alone Around the World" he talks about his tin clock:

  "My tin clock and only timepiece had by this time lost its minute-hand, 
   but after I boiled her she told the hours, and that was near enough on
   a long stretch." 

If Slocum was able to successfully circumnavigate via celestial navigation
using a clock with no minute hand, then modern day sailors should be able
to get by using weather forecasts without floating point precision.


